@@ -1,8 +1,6 @@
 from django import template
-from django.templatetags.static import PrefixNode
 
 from ..sitetreeapp import SiteTree
-from ..utils import DJANGO_VERSION_INT
 
 register = template.Library()
 
@@ -10,7 +8,6 @@ register = template.Library()
 sitetree = SiteTree()
 
 
-
 @register.tag
 def sitetree_tree(parser, token):
     """Parses sitetree tag parameters.
@@ -34,7 +31,7 @@ def sitetree_tree(parser, token):
         tree_alias = parser.compile_filter(tokens[2])
         return sitetree_treeNode(tree_alias, use_template)
     else:
-        raise template.TemplateSyntaxError, "%r tag requires two arguments. E.g. {%% sitetree_tree from \"mytree\" %%}." % tokens[0]
+        raise template.TemplateSyntaxError("%r tag requires two arguments. E.g. {%% sitetree_tree from \"mytree\" %%}." % tokens[0])
 
 
 @register.tag
@@ -60,7 +57,7 @@ def sitetree_children(parser, token):
         navigation_type = tokens[4]
         return sitetree_childrenNode(tree_item, navigation_type, use_template)
     else:
-        raise template.TemplateSyntaxError, "%r tag requires six arguments. E.g. {%% sitetree_children of someitem for menu template \"sitetree/mychildren.html\" %%}." % tokens[0]
+        raise template.TemplateSyntaxError("%r tag requires six arguments. E.g. {%% sitetree_children of someitem for menu template \"sitetree/mychildren.html\" %%}." % tokens[0])
 
 
 @register.tag
@@ -86,7 +83,7 @@ def sitetree_breadcrumbs(parser, token):
         tree_alias = parser.compile_filter(tokens[2])
         return sitetree_breadcrumbsNode(tree_alias, use_template)
     else:
-        raise template.TemplateSyntaxError, "%r tag requires two arguments. E.g. {%% sitetree_breadcrumbs from \"mytree\" %%}." % tokens[0]
+        raise template.TemplateSyntaxError("%r tag requires two arguments. E.g. {%% sitetree_breadcrumbs from \"mytree\" %%}." % tokens[0])
 
 
 @register.tag
@@ -117,7 +114,7 @@ def sitetree_menu(parser, token):
         tree_branches = parser.compile_filter(tokens[4])
         return sitetree_menuNode(tree_alias, tree_branches, use_template)
     else:
-        raise template.TemplateSyntaxError, "%r tag requires four arguments. E.g. {%% sitetree_menu from \"mytree\" include \"trunk,1,level3\" %%}." % tokens[0]
+        raise template.TemplateSyntaxError("%r tag requires four arguments. E.g. {%% sitetree_menu from \"mytree\" include \"trunk,1,level3\" %%}." % tokens[0])
 
 
 @register.tag
@@ -137,9 +134,11 @@ def sitetree_url(parser, token):
             tokens = tokens[:-2]
         sitetree_item = parser.compile_filter(tokens[2])
         tag_arguments = map(parser.compile_filter, tokens[3:])
+        if not tag_arguments:
+            tag_arguments = None
         return sitetree_urlNode(sitetree_item, as_var, tag_arguments)
     else:
-        raise template.TemplateSyntaxError, "%r tag should look like {%% sitetree_url for someitem params %%}." % tokens[0]
+        raise template.TemplateSyntaxError("%r tag should look like {%% sitetree_url for someitem params %%}." % tokens[0])
 
 
 @register.tag
@@ -154,16 +153,7 @@ def sitetree_page_title(parser, token):
         tree_alias = parser.compile_filter(tokens[2])
         return sitetree_page_titleNode(tree_alias)
     else:
-        raise template.TemplateSyntaxError, "%r tag requires two arguments. E.g. {%% sitetree_page_title from \"mytree\" %%}." % tokens[0]
-
-
-@register.simple_tag
-def sitetree_admin_img_url_prefix():
-    """Returns static admin images URL prefix. """
-    if DJANGO_VERSION_INT >= 140:
-        return '%sadmin/img' % PrefixNode.handle_simple('STATIC_URL')
-
-    return '%simg/admin' % PrefixNode.handle_simple('ADMIN_MEDIA_PREFIX')
+        raise template.TemplateSyntaxError("%r tag requires two arguments. E.g. {%% sitetree_page_title from \"mytree\" %%}." % tokens[0])
 
 
 class sitetree_treeNode(template.Node):
